@@ -52,9 +52,8 @@ BaremetalGroup = [
     cfg.StrOpt('catalog_type',
                default='baremetal',
                help="Catalog type of the baremetal provisioning service"),
-    # TODO(dtantsur): change to fake-hardware when Ocata is no longer supported
     cfg.StrOpt('driver',
-               default='fake',
+               default='fake-hardware',
                help="Driver name to use for API tests"),
     cfg.StrOpt('endpoint_type',
                default='publicURL',
@@ -143,7 +142,14 @@ BaremetalGroup = [
                     "as instance_info/root_gb value."),
     cfg.IntOpt('available_nodes', min=0, default=None,
                help="The number of baremetal hosts available to use for "
-                    "the tests.")
+                    "the tests."),
+    cfg.BoolOpt('partition_netboot',
+                default=True,
+                help="Treat partition images as netbooted as opposed to "
+                     "attempting to populate a boot loader. IF cirros is "
+                     "being used, this option should be set to True as "
+                     "it lacks the needed components to make it locally "
+                     "from a partition image."),
 ]
 
 BaremetalFeaturesGroup = [
@@ -178,6 +184,9 @@ BaremetalIntrospectionGroup = [
     cfg.IntOpt('introspection_timeout',
                default=600,
                help="Introspection time out"),
+    cfg.IntOpt('introspection_start_timeout',
+               default=90,
+               help="Timeout to start introspection"),
     cfg.IntOpt('hypervisor_update_sleep',
                default=60,
                help="Time to wait until nova becomes aware of "
