@@ -79,12 +79,17 @@ class BaremetalCleaningIpmiWholedisk(
 
 class SoftwareRaidIscsi(bsm.BaremetalStandaloneScenarioTest):
 
-    driver = 'ipmi'
+    if 'redfish' in CONF.baremetal.enabled_hardware_types:
+        driver = 'redfish'
+    else:
+        driver = 'ipmi'
     image_ref = CONF.baremetal.whole_disk_image_ref
     wholedisk_image = True
     deploy_interface = 'iscsi'
     raid_interface = 'agent'
     api_microversion = '1.31'
+    # Software RAID is always local boot
+    boot_option = 'local'
 
     raid_config = {
         "logical_disks": [
@@ -99,6 +104,8 @@ class SoftwareRaidIscsi(bsm.BaremetalStandaloneScenarioTest):
     @classmethod
     def skip_checks(cls):
         super(SoftwareRaidIscsi, cls).skip_checks()
+        if cls.driver == 'ipmi':
+            raise cls.skipException("Testing with redfish driver")
         if not CONF.baremetal_feature_enabled.software_raid:
             raise cls.skipException("Software RAID feature is not enabled")
 
@@ -106,16 +113,30 @@ class SoftwareRaidIscsi(bsm.BaremetalStandaloneScenarioTest):
     @utils.services('image', 'network')
     def test_software_raid(self):
         self.build_raid_and_verify_node()
+        # NOTE(TheJulia): tearing down/terminating the instance does not
+        # remove the root device hint, so it is best for us to go ahead
+        # and remove it before exiting the test.
+        self.remove_root_device_hint()
+        # Removes RAID configuration
+        # TODO(TheJulia): We _should_ tear the raid configuration down
+        # however bouncing neutron ports with known DHCP reload bugs
+        # is not a super great idea for tempest tests.
+        self.remove_raid_configuration()
 
 
 class SoftwareRaidDirect(bsm.BaremetalStandaloneScenarioTest):
 
-    driver = 'ipmi'
+    if 'redfish' in CONF.baremetal.enabled_hardware_types:
+        driver = 'redfish'
+    else:
+        driver = 'ipmi'
     image_ref = CONF.baremetal.whole_disk_image_ref
     wholedisk_image = True
     deploy_interface = 'direct'
     raid_interface = 'agent'
     api_microversion = '1.31'
+    # Software RAID is always local boot
+    boot_option = 'local'
 
     # TODO(dtantsur): more complex layout in this job
     raid_config = {
@@ -131,6 +152,8 @@ class SoftwareRaidDirect(bsm.BaremetalStandaloneScenarioTest):
     @classmethod
     def skip_checks(cls):
         super(SoftwareRaidDirect, cls).skip_checks()
+        if cls.driver == 'redfish':
+            raise cls.skipException("Testing with ipmi driver")
         if not CONF.baremetal_feature_enabled.software_raid:
             raise cls.skipException("Software RAID feature is not enabled")
 
@@ -138,3 +161,12 @@ class SoftwareRaidDirect(bsm.BaremetalStandaloneScenarioTest):
     @utils.services('image', 'network')
     def test_software_raid(self):
         self.build_raid_and_verify_node()
+        # NOTE(TheJulia): tearing down/terminating the instance does not
+        # remove the root device hint, so it is best for us to go ahead
+        # and remove it before exiting the test.
+        self.remove_root_device_hint()
+        # Removes RAID configuration
+        # TODO(TheJulia): We _should_ tear the raid configuration down
+        # however bouncing neutron ports with known DHCP reload bugs
+        # is not a super great idea for tempest tests.
+        self.remove_raid_configuration()
